@@ -1,8 +1,19 @@
+"""
+===================
+psimulate Constants
+===================
 
+Shared constants for psimulate runs.
+"""
 
 # Cluster projects under the purview of Simulation Science
-CLUSTER_PROJECTS = ['proj_cost_effect', 'proj_cost_effect_diarrhea', 'proj_cost_effect_dcpn', 'proj_cost_effect_conic',
-                    'proj_csu']
+CLUSTER_PROJECTS = [
+    'proj_cost_effect',
+    'proj_cost_effect_diarrhea',
+    'proj_cost_effect_dcpn',
+    'proj_cost_effect_conic',
+    'proj_csu',
+]
 DEFAULT_CLUSTER_PROJECT = 'proj_cost_effect'
 
 DEFAULT_OUTPUT_DIRECTORY = '/share/costeffectiveness/results'
