@@ -1,3 +1,11 @@
+"""
+================
+psimulate Runner
+================
+
+The main process loop for `psimulate` runs.
+
+"""
 import os
 import atexit
 import math
@@ -185,13 +193,18 @@ def get_random_free_port() -> int:
     return port
 
 
-def launch_redis(port: int) -> subprocess.Popen:
+def launch_redis(port: int, logging_dirs: Dict) -> subprocess.Popen:
+    log = open(f'{logging_dirs["main"]}/redis.p{port}.log', 'a')
+    log.write(f'>>>>>>>> Starting log for redis-server on port {port}\n')
+    log.flush()
     try:
         # inline config for redis server.
         redis_process = subprocess.Popen(["redis-server", "--port", f"{port}",
                                           "--timeout", "2",
-                                          "--protected-mode", "no"], stdout=subprocess.DEVNULL,
-                                         stderr=subprocess.DEVNULL)
+                                          "--loglevel", "debug",
+                                         # "--daemonize", "yes",
+                                          "--protected-mode", "no"], stdout=log,
+                                         stderr=log)
     except FileNotFoundError:
         raise OSError("In order for redis to launch you need both the redis client and the python bindings. "
                       "You seem to be missing the redis client.  Do 'conda install redis' and try again. If "
@@ -200,13 +213,13 @@ def launch_redis(port: int) -> subprocess.Popen:
     return redis_process
 
 
-def launch_redis_processes(num_processes: int) -> (str, List[Tuple[str, int]]):
+def launch_redis_processes(num_processes: int, logging_dirs: Dict) -> Tuple[str, List[Tuple[str, int]]]:
     hostname = socket.getfqdn()
     redis_ports = []
     for i in range(num_processes):
         port = get_random_free_port()
         logger.info(f'Starting Redis Broker at {hostname}:{port}')
-        launch_redis(port)
+        launch_redis(port, logging_dirs)
         redis_ports.append((hostname, port))
 
     redis_urls = [f'redis://{hostname}:{port}' for hostname, port in redis_ports]
@@ -318,8 +331,10 @@ def concat_results(old_results: pd.DataFrame, new_results: List[pd.DataFrame]) -
     return results
 
 
-def write_results_batch(ctx: RunContext, written_results: pd.DataFrame, unwritten_results: List[pd.DataFrame],
-                        batch_size: int = 50) -> (pd.DataFrame, List[pd.DataFrame]):
+def write_results_batch(ctx: RunContext,
+                        written_results: pd.DataFrame,
+                        unwritten_results: List[pd.DataFrame],
+                        batch_size: int = 50) -> Tuple[pd.DataFrame, List[pd.DataFrame]]:
     new_results_to_write, unwritten_results = (unwritten_results[:batch_size], unwritten_results[batch_size:])
     results_to_write = concat_results(written_results, new_results_to_write)
 
@@ -437,7 +452,7 @@ def main(model_specification_file: str, branch_configuration_file: str, artifact
     if redis_processes == -1:
         redis_processes = int(math.ceil(len(jobs) / vct_globals.DEFAULT_JOBS_PER_REDIS_INSTANCE))
 
-    worker_template, redis_ports = launch_redis_processes(redis_processes)
+    worker_template, redis_ports = launch_redis_processes(redis_processes, logging_dirs)
     worker_file = output_dir / 'settings.py'
     with worker_file.open('w') as f:
         f.write(worker_template)
